import { Component, Input } from '@angular/core';
import { TrendLineType_$type } from "igniteui-angular-core";
import { IgxRadialBaseComponent } from "./igx-radial-base-component";
import { ensureEnum, brushToString, stringToBrush, toDoubleCollection, fromDoubleCollection, toPoint, fromPoint } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents the base class for all IgxDataChartComponent anchored radial category series.
*/
export let IgxAnchoredRadialSeriesComponent = /*@__PURE__*/ (() => {
    class IgxAnchoredRadialSeriesComponent extends IgxRadialBaseComponent {
        constructor() {
            super();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        /**
         * Gets or sets the item path that provides the values for the current series.
        */
        get valueMemberPath() {
            return this.i.xm;
        }
        set valueMemberPath(v) {
            this.i.xm = v;
        }
        /**
         * Gets or sets the value mapping property for the current series object.
        */
        get highlightedValueMemberPath() {
            return this.i.xf;
        }
        set highlightedValueMemberPath(v) {
            this.i.xf = v;
        }
        /**
         * Gets or sets the label displayed before series value in the Data Legend.
        */
        get valueMemberAsLegendLabel() {
            return this.i.xi;
        }
        set valueMemberAsLegendLabel(v) {
            this.i.xi = v;
        }
        /**
         * Gets or sets the unit displayed after series value in the Data Legend.
        */
        get valueMemberAsLegendUnit() {
            return this.i.xk;
        }
        set valueMemberAsLegendUnit(v) {
            this.i.xk = v;
        }
        /**
         * Gets or sets the trend type for the current series object.
        */
        get trendLineType() {
            return this.i.w2;
        }
        set trendLineType(v) {
            this.i.w2 = ensureEnum(TrendLineType_$type, v);
        }
        /**
         * Gets or sets the brush that specifies how to the current series
         * object's Trend line is drawn.
        */
        get trendLineBrush() {
            return brushToString(this.i.x7);
        }
        set trendLineBrush(v) {
            this.i.x7 = stringToBrush(v);
        }
        /**
         * Gets the effective TrendLineBrush for this series.
        */
        get actualTrendLineBrush() {
            return brushToString(this.i.x6);
        }
        set actualTrendLineBrush(v) {
            this.i.x6 = stringToBrush(v);
        }
        /**
         * Gets or sets the thickness of the current series object's trend line.
        */
        get trendLineThickness() {
            return this.i.xc;
        }
        set trendLineThickness(v) {
            this.i.xc = +v;
        }
        /**
         * Gets or sets a collection of double values that indicate the pattern of dashes and gaps that
         * is used to draw the trend line for the current series object.
        */
        get trendLineDashArray() {
            return fromDoubleCollection(this.i.x8);
        }
        set trendLineDashArray(v) {
            this.i.x8 = toDoubleCollection(v);
        }
        /**
         * Gets or sets the trend line period for the current series.
         * The typical, and initial, value for bollinger band periods is 20.
        */
        get trendLinePeriod() {
            return this.i.xd;
        }
        set trendLinePeriod(v) {
            this.i.xd = +v;
        }
        /**
         * Sets or Gets the Z index of the trendline.
        */
        get trendLineZIndex() {
            return this.i.xe;
        }
        set trendLineZIndex(v) {
            this.i.xe = +v;
        }
        get hasValueAxis() {
            return this.i.d0;
        }
        get isValueAxisInverted() {
            return this.i.fj;
        }
        getItemValue(item, memberPathName) {
            let iv = this.i.jv(item, memberPathName);
            return (iv);
        }
        getPreviousOrExactIndex(world, skipUnknowns) {
            let iv = this.i.jg(toPoint(world), skipUnknowns);
            return (iv);
        }
        getNextOrExactIndex(world, skipUnknowns) {
            let iv = this.i.je(toPoint(world), skipUnknowns);
            return (iv);
        }
        getSeriesValue(world, useInterpolation, skipUnknowns) {
            let iv = this.i.ia(toPoint(world), useInterpolation, skipUnknowns);
            return (iv);
        }
        getSeriesValuePosition(world, useInterpolation, skipUnknowns) {
            let iv = this.i.tj(toPoint(world), useInterpolation, skipUnknowns);
            return fromPoint(iv);
        }
        /**
         * Returns the offset value for this series if grouped on a category axis.
        
        */
        getOffsetValue() {
            let iv = this.i.getOffsetValue();
            return (iv);
        }
        /**
         * Returns the width of the category grouping this series is in.
        
        */
        getCategoryWidth() {
            let iv = this.i.getCategoryWidth();
            return (iv);
        }
        /**
         * Scrolls the specified item into the view.
        
        * @param item  * The item to scroll into view.
        */
        scrollIntoView(item) {
            let iv = this.i.fp(item);
            return (iv);
        }
    }
    IgxAnchoredRadialSeriesComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxAnchoredRadialSeriesComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxAnchoredRadialSeriesComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: IgxAnchoredRadialSeriesComponent, selector: "ng-component", inputs: { valueMemberPath: "valueMemberPath", highlightedValueMemberPath: "highlightedValueMemberPath", valueMemberAsLegendLabel: "valueMemberAsLegendLabel", valueMemberAsLegendUnit: "valueMemberAsLegendUnit", trendLineType: "trendLineType", trendLineBrush: "trendLineBrush", actualTrendLineBrush: "actualTrendLineBrush", trendLineThickness: "trendLineThickness", trendLineDashArray: "trendLineDashArray", trendLinePeriod: "trendLinePeriod", trendLineZIndex: "trendLineZIndex" }, usesInheritance: true, ngImport: i0, template: ``, isInline: true });
    return IgxAnchoredRadialSeriesComponent;
})();
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxAnchoredRadialSeriesComponent, decorators: [{
            type: Component,
            args: [{
                    template: ``,
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { valueMemberPath: [{
                type: Input
            }], highlightedValueMemberPath: [{
                type: Input
            }], valueMemberAsLegendLabel: [{
                type: Input
            }], valueMemberAsLegendUnit: [{
                type: Input
            }], trendLineType: [{
                type: Input
            }], trendLineBrush: [{
                type: Input
            }], actualTrendLineBrush: [{
                type: Input
            }], trendLineThickness: [{
                type: Input
            }], trendLineDashArray: [{
                type: Input
            }], trendLinePeriod: [{
                type: Input
            }], trendLineZIndex: [{
                type: Input
            }] } });
